Crate kcr_operator_cryostat_io

Crate kcr_operator_cryostat_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the operator.cryostat.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

operator.cryostat.io/v1beta1

  • Cryostat

operator.cryostat.io/v1beta2

  • Cryostat

Modules

v1beta1
v1beta2